//+------------------------------------------------------------------+
//|                                              sysExtremeRev.0.mq5 |
//|                                         Copyright 2019, NickBixy |
//|                           https://www.mql5.com/en/users/nickbixy |
//+------------------------------------------------------------------+
#property copyright "Copyright 2019, NickBixy"
#property link      "https://www.mql5.com/en/users/nickbixy"
#property version   "1.00"
#property strict
#property indicator_chart_window
#property indicator_buffers 2
#property indicator_plots   2

#property indicator_type1   DRAW_ARROW
#property indicator_color1  clrOrangeRed
#property indicator_width1  1

#property indicator_type2   DRAW_ARROW
#property indicator_color2  clrAqua
#property indicator_width2  1

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
input double bodySizeP=.525;
input int barsBack=50;
input double bodyMultiplier=2;

input string info="https://docs.mql4.com/constants/objectconstants/wingdings";//Windings font symbols
input int arrowWinding=167;//Arrow Wingding Character

double BEARISH[];
double BULLISH[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {
   IndicatorSetString(INDICATOR_SHORTNAME,"sysExtremeRev");

//Bearish Set up
   SetIndexBuffer(0,BEARISH,INDICATOR_DATA);
   PlotIndexSetString(0,PLOT_LABEL,"sysExtremeRev Bearish");
   PlotIndexSetInteger(0,PLOT_ARROW,arrowWinding);
   PlotIndexSetInteger(0,PLOT_ARROW_SHIFT,-10);
   PlotIndexSetDouble(0,PLOT_EMPTY_VALUE,0.0);

//Bullish Set up
   SetIndexBuffer(1,BULLISH,INDICATOR_DATA);
   PlotIndexSetString(1,PLOT_LABEL,"sysExtremeRev Bullish");
   PlotIndexSetInteger(1,PLOT_ARROW,arrowWinding);
   PlotIndexSetInteger(1,PLOT_ARROW_SHIFT,10);
   PlotIndexSetDouble(1,PLOT_EMPTY_VALUE,0.0);

   ArrayInitialize(BEARISH,0.0);
   ArrayInitialize(BULLISH,0.0);

   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {

   int limit;
   int counted_bars=IndicatorCountedMQL4(prev_calculated);
//---- check for possible errors
   if(counted_bars<0)
      return(-1);
//---- the last counted bar will be recounted

   if(counted_bars>0)
      counted_bars--;

   limit=Bars(_Symbol,PERIOD_CURRENT)-counted_bars;

   for(int i=0; i<limit; i++)
     {
      double bodySizeTotal=0;
      double candleSizeTotal=0;
      for(int j=1; j<=barsBack; j++)
        {
         bodySizeTotal+=MathAbs(close[i+j]-open[i+j]);
         candleSizeTotal+=high[i+j]-low[i+j];
        }

      double bodySize=MathAbs(close[i]-open[i]);
      double averageBodySize=bodySizeTotal/barsBack;

      double candleSize=high[i]-low[i];
      double averageCandleSize=candleSizeTotal/barsBack;

      if(((open[i+1]-close[i+1])>=(bodySizeP*(high[i+1]-low[i+1])))
         &&
         ((high[i+1]-low[i+1]) > (averageCandleSize*bodyMultiplier))
         &&
         ((open[i+1]-close[i+1]) > averageBodySize)
         &&
         (close[i]>open[i]))
        {
         BULLISH[i]=low[i];
         BEARISH[i]=0.0;
        }
      else
         if(((close[i+1]-open[i+1])>=(bodySizeP*(high[i+1]-low[i+1])))
            &&
            ((high[i+1]-low[i+1])> (averageCandleSize*bodyMultiplier))
            &&
            ((close[i+1]-open[i+1])> averageBodySize)
            &&
            (open[i]>close[i])
           )
           {
            BEARISH[i]=high[i];
            BULLISH[i]=0.0;
           }
         else
           {
            BEARISH[i]=0.0;
            BEARISH[i]=0.0;
           }
     }

   return(rates_total);
  }
//+------------------------------------------------------------------+
int IndicatorCountedMQL4(int prev_calculated)
  {
   if(prev_calculated>0)
      return(prev_calculated-1);
   if(prev_calculated==0)
      return(0);
   return(0);
  }
//+------------------------------------------------------------------+
